@@ -228,7 +228,7 @@ sub gnCheckPath {
    # ファイルやディレクトリが存在するかどうかチェックする関数
    #
    # 引数１：文字列(ファイルパス, utf8フラグ付きを想定)
-   # 返り値：文字列(ある=0以外、ない=0)
+   # 返り値：文字列(ない=0、ファイル=1、ディレクトリ=2、その他=3)
    my $path = $_[0];
    my $pathN = &gnFnEncode($path);
    if(!($path)) {
@@ -236,11 +236,16 @@ sub gnCheckPath {
       return(0);
    }
    if(-e $pathN) {
-      if ($main::gnDebugFlag>2) { print STDERR "gnCheckPath Found: $pathN\n"; }
-      return(1);
-   }else{
-      if ($main::gnDebugFlag>2) { print STDERR "gnCheckPath NOT Found: $pathN\n"; }
-      return(0);
+      if(-f $pathN) {
+         if ($main::gnDebugFlag>2) { print STDERR "gnCheckPath Found\(Simple File\): $pathN\n"; }
+         return(1);
+      }elsif(-d $pathN) {
+         if ($main::gnDebugFlag>2) { print STDERR "gnCheckPath Found\(Directory\): $pathN\n"; }
+         return(2);
+      }else{
+         if ($main::gnDebugFlag>2) { print STDERR "gnCheckPath Found\(Unknown File\): $pathN\n"; }
+         return(3);
+      }
    }
 }
 
